package p10_importowanie;

import static p09_funkcje.Geometria.*;
import static p09_funkcje.JednostkiMiary.*;
import static java.lang.Math.*;

import java.util.Scanner;

/* import static pakiet.Klasa.* importuje wszystkie rzeczy statyczne z podanej klasy.
 *
 * Nie da się użyć gwiazdek na poziomie pakietu i klasy w jednym imporcie.
 * To nie przejdzie:
 * import static p09_funkcje.*.*;
 */
public class Program5 {

	public static void main(String[] args) {
		// Tylko, żeby pokazać dizałanie Math.*
		System.out.println("pi: " + PI);
		System.out.println("pierwiastek z 2 " + sqrt(2));
		
		@SuppressWarnings("resource")
		Scanner scanner = new Scanner(System.in);
		
		System.out.println("  K  - kwadrat");
		System.out.println("  O  - koło");
		System.out.println("  P  - prostokąt");
		System.out.println("  T  - trójkąt");
		System.out.println("  KM - przelicz kilometry na mile");
		System.out.println("  MK - przelicz mile na kilometry");
		System.out.println("  CF - przelicz °C na °F");
		System.out.println("  FC - przelicz °F na °C");
		System.out.println("  Q  - zakończ");
		
		petla:
		while(true) {
			System.out.println("\nWybierz figurę lub operację:");
			
			String wybor = scanner.next().toUpperCase();

			switch(wybor) {
				case "Q" -> {
					break petla;
				}
				case "K" -> {
					System.out.print("Podaj długość boku kwadratu: ");
					double a = scanner.nextDouble();
					double pole = poleKwadratu(a);
					double obwod = obwodKwadratu(a);
					System.out.printf("Dla kwadratu o boku %.3f pole wynosi %.3f, a obwód %.3f\n", a, pole, obwod);
				}
				case "P" -> {
					System.out.print("Podaj dwie długości boków prostokąta: ");
					double a = scanner.nextDouble();
					double b = scanner.nextDouble();
					double pole = poleProstokata(a, b);
					double obwod = obwodProstokata(a, b);
					System.out.printf("Dla prostokąta o bokach %.3f i %.3f pole wynosi %.3f, a obwód %.3f\n", a, b, pole, obwod);
				}
				case "O" -> {
					System.out.print("Podaj promień koła: ");
					double r = scanner.nextDouble();
					double pole = poleKola(r);
					double obwod = obwodKola(r);
					System.out.printf("Dla koła o promieniu %.3f pole wynosi %.3f, a obwód %.3f\n", r, pole, obwod);
				}
                case "T" -> {
                    System.out.print("Podaj trzy długości boków trójkąta: ");
                    double a = scanner.nextDouble();
                    double b = scanner.nextDouble();
                    double c = scanner.nextDouble();
                    if(warunekTrojkata(a, b, c)) {
	                    double pole = poleTrojkata(a, b, c);
	                    double obwod = obwodTrojkata(a, b, c);
	                    System.out.printf("Dla prostokąta o bokach %.3f %.3f %.3f pole wynosi %.3f, a obwód %.3f\n", a, b, c, pole, obwod);
                    } else {
                    	System.out.println("Z tych liczb nie da się złożyć trójkąta");
                    }
                }
                case "KM" -> {
                    System.out.print("Podaj odległość w kilometrach: ");
                    double km = scanner.nextDouble();
                    double wynik = km_na_mile(km);
                    System.out.printf("%.3f km = %.3f mil\n", km, wynik);
                }
                case "MK" -> {
                    System.out.print("Podaj odległość w milach: ");
                    double mile = scanner.nextDouble();
                    double wynik = mile_na_km(mile);
                    System.out.printf("%.3f mil = %.3f km\n", mile, wynik);
                }
                case "FC" -> {
                    System.out.print("Podaj temperaturę w Fahrenheitach: ");
                    double f = scanner.nextDouble();
                    double wynik = f_na_c(f);
                    System.out.printf("%.3f °F = %.3f °C\n", f, wynik);
                }
                case "CF" -> {
                    System.out.print("Podaj temperaturę w Celsjuszach: ");
                    double c = scanner.nextDouble();
                    double wynik = c_na_f(c);
                    System.out.printf("%.3f °C = %.3f °F\n", c, wynik);
                }
                default -> {
					System.out.println("Nieznane polecenie " + wybor);
				}
			}
		}
		System.out.println("Dzięki, miłego dnia!");
	}

}